<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\Processing\Steps;

use DM\Processing\Step;

class ArchivateDemo extends Step
{
    /**
     * Uploading demo content pack from repository
     * @return boolean
     * @throws Exception
     */
    protected function processing()
    {
        $zip_path = $this->getDemo()->getDemoZipFilePath();
        $files_path = $this->getDemo()->getDemoDir();
        
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        if (file_exists($zip_path)) {
            $wp_filesystem->delete($zip_path);
        }
        
        // Initialize archive object
        $zip = new \ZipArchive();
        $zip->open($zip_path, \ZipArchive::CREATE | \ZipArchive::OVERWRITE);

        // Create recursive directory iterator
        /** @var SplFileInfo[] $files */
        $files = new \RecursiveIteratorIterator(
                new \RecursiveDirectoryIterator($files_path), \RecursiveIteratorIterator::LEAVES_ONLY
        );

        foreach ($files as $name => $file) {
            // Skip directories (they would be added automatically)
            if (!$file->isDir()) {
                // Get real and relative path for current file
                $filePath = $file->getRealPath();
                $relativePath = substr($filePath, strlen($files_path));

                // Add current file to archive
                $zip->addFile($filePath, $this->getDemo()->getId() . DIRECTORY_SEPARATOR . $relativePath);
            }
        }

        // Zip archive will be created only after closing object
        $zip->close();

        return true;
    }
    
    protected function abort()
    {
        $zip_path = $this->getDemo()->getDemoZipFilePath();
        
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        if (file_exists($zip_path)) {
            $wp_filesystem->delete($zip_path);
        }
        
        return true;
    }
}

