<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\Processing\Steps;

use DM\Processing\Step;

class ExtractDbTables extends Step
{
    protected $table_offset = null;
    protected $rows_offset = null;

    public function __construct(\DM\Log $Log, $Demo) {
        parent::__construct($Log, $Demo);
        $this->table_offset = $this->getTableOffset();
        $this->rows_offset = $this->getRowOffset();
    }
    
    protected function processing()
    {
        $this->getLog()->addLog('Extract tables in the database');
        $this->extractTables();
        
        $this->getLog()->addLog('Change demo site administrator');
        $this->changeAdministratorUser();
        
        return true;
    }
    
    protected function abort()
    {
        return true;
    }

    public function extractTables()
    {
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        $tables = $this->getDemo()->getTablesList();
        $prefix = $this->getDemo()->getTablePrefix();
        
        foreach ($tables as $key => $table_name) {
            if ( $key < $this->table_offset ) {
                continue;
            }
            $this->getLog()->addLog('Extract table data: ' . $table_name);
            
            $full_table_name = $prefix . $table_name;
            $table_file_dir = $this->getDemo()->getDbDir() . "/$table_name.json";
            $table_json = $wp_filesystem->get_contents($table_file_dir);
            $table_data = json_decode($table_json);
            
            $this->extractRows($full_table_name, $table_data, $key);
        }
    }
    
        public function extractRows($full_table_name, $table_data, $table_position)
        {
            foreach ($table_data as $row_position => $row) {
                if ( $row_position <= $this->rows_offset ) {
                    continue;
                }
                
                $result_row = array();
                foreach ($row as $key => $value) {
                    $clear_value = $this->prepareArray($value);
                    if (is_array($clear_value) || is_object($clear_value)) {
                        $result_row[$key] = serialize($clear_value);
                    } else {
                        $result_row[$key] = $clear_value;
                    }
                }

                $this->getDB()->insert($full_table_name, $result_row);
                
                $this->getStatuses()->changeStatusData(array(
                    'table_offset' => $table_position, 
                    'row_offset' => $row_position
                ));
            }
        }
    
            public function prepareArray($object)
            {
                if (is_array($object) || is_object($object)) {
                    $result = array();
                    foreach ($object as $key => $value) {
                        $result[$key] = $this->prepareArray($value);
                    }
                    
                    return $result;
                }
                
                
                if ($this->getDemo()->getUploadsUrl()) {
                    $upload_dir_information = wp_upload_dir();
                    $object = str_replace($this->getDemo()->getUploadsUrl(), $upload_dir_information['baseurl'], $object);
                }
                
                $replaced_url = str_replace($this->getDemo()->getSiteUrl(), get_site_url(), $object);
                
                return $replaced_url;
            }
            
    protected function getTableOffset()
    {
        $data = $this->getStatuses()->getCurrentStatusData();
        if (isset($data['table_offset'])) {
            return (int)$data['table_offset'];
        }
        
        return 0;
    }
    
    protected function getRowOffset()
    {
        $data = $this->getStatuses()->getCurrentStatusData();
        if (isset($data['row_offset'])) {
            return (int)$data['row_offset'];
        }
        
        return -1;
    }
    
    public function changeAdministratorUser()
    {
        global $wpdb;
        global $table_prefix;
        $query = "SELECT * FROM ". $table_prefix ."users WHERE ID = 1";
        $administrator_data = $wpdb->get_row($query, 'ARRAY_A');
        
        unset($administrator_data['id']);
        $wpdb->update($this->getDemo()->getTablePrefix() . "users", $administrator_data, array('ID' => 1));
    }
    
    
}

