<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\Processing\Steps;

use DM\Processing\Step;
use DM\Manager;

class UploadDemoContent extends Step
{
    /**
     * Uploading demo content pack from repository
     * @return boolean
     * @throws Exception
     */
    protected function processing()
    {
        $this->abort();
        
        if (!$this->getDemo()->isUploaded()) {
            $this->getDemo()->upload();
        }
        
        if (!$this->getDemo()->isUploaded()) {
            throw new \Exception('Uploading error: demo content not found after uploading.');
        }
        
        return true;
    }
    
    protected function abort()
    {
        if ($this->getDemo()->isUploaded() === false) {
            return true;
        }
        
        // Do not deleting if this process of installation demo from local repository
        if ($this->getDemo()->version === \DM\Manager::LOCAL && 
            $this->getProcess()->getProcessId() === 'dm_Installer' || 
            $this->getDemo()->version === \DM\Manager::INSTALLED &&
            $this->getProcess()->getProcessId() === 'dm_Installer') {
            return;
        }
        
        // Not deleting if remoute installation and local version matched!
        if ($this->getProcess()->getProcessId() === 'dm_Installer' &&
            $this->getDemo()->version === \DM\Manager::REMOUTE) {
            $demo_id = $this->getDemo()->getId();
            $LocalDemo = Manager::getInstance()->getById($demo_id, Manager::LOCAL);
            if ($LocalDemo && $LocalDemo->getDateCreation() == $this->getDemo()->getDateCreation()) {
                return;
            }
        }
        
        $this->getLog()->addLog('Deleting demo souce file from local sorage');
        $this->getDemo()->remove();
        
        return true;
    }
}

