<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM;

use DM\Config;

if (!class_exists('WP_Filesystem_FTPext')) {
    include ABSPATH . 'wp-admin/includes/class-wp-filesystem-ftpext.php';
}

class Repository
{
    protected $host = null;
    protected $user = null;
    protected $password = null;
    protected $FTP = null;
    protected $Config = null;
    
    private static $_instance = null;
    
    /**
     * @return \DM\Repository
     */
    static public function getInstance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        
        return self::$_instance;
    }
    
    public function __construct()
    {
        $this->Config = Config::getInstance();
        $this->host = $this->Config->getSettingValue('ftp_host');
        $this->user = $this->Config->getSettingValue('ftp_user');
        $this->password = $this->Config->getSettingValue('ftp_password');
        
        $this->FTP = new \WP_Filesystem_FTPext(array(
            'hostname' => $this->host,
            'username' => $this->user,
            'password' => $this->password
        ));
        
        $this->FTP->connect();
    }
    
    public function deployDemo(\DM\Demo $Demo)
    {
        $file_name = $Demo->getDemoZipFileName();
        $zip_demo_pack = $this->Config->getDemosDir() . $file_name;
        if (!file_exists($zip_demo_pack)) {
            throw new \Exception('Zip demo pack not fount');
        }
        
        $wp_filesystem = \DM\WPObjects\FileSystem\FileSystem::getInstance();
        $content = $wp_filesystem->get_contents($zip_demo_pack);
        if ($this->FTP->exists($file_name)) {
            $this->FTP->delete($file_name);
        }
        $this->FTP->put_contents($file_name, $content);
        $this->changeDemoConfig($Demo->toArray());
        return true;
    }
    
    public function deleteDemo($demo_id)
    {
        $file_name = $demo_id . '.zip';
        if ($this->FTP->exists($file_name)) {
            $this->FTP->delete($file_name);
        }
        
        $Config = $this->getConfig();
        foreach ($Config as $key => $demo_data) {
            if ($demo_data['id'] === $demo_id) {
                unset($Config[$key]);
            }
        }
        
        $this->putConfig($Config);
        return true;
    }
    
    protected function changeDemoConfig($new_config)
    {
        $Config = $this->getConfig();
        foreach ($Config as $key => $demo_data) {
            if ($demo_data['id'] === $new_config['id']) {
                $Config[$key] = $new_config;
                $this->putConfig($Config);
                return;
            }
        }
        
        $Config[] = $new_config;
        $this->putConfig($Config);
        return;
    }
    
    protected function getConfig()
    {
        $config_json = $this->FTP->get_contents('list.json');
        $Config = json_decode($config_json, true);
        if (!is_array($Config)) {
            $Config = array();
        }
        
        return $Config;
    }
    
    protected function putConfig($config)
    {
        $config_json = json_encode($config, JSON_PRETTY_PRINT);
        return $this->FTP->put_contents('list.json', $config_json);
    }
    
    
    
}

